@@ -1603,7 +1603,7 @@ use warnings;
 
 package Devel::PerlySense;
 {
-  $Devel::PerlySense::VERSION = '0.0194';
+  $Devel::PerlySense::VERSION = '0.0195';
 }
 
 
@@ -1665,7 +1665,7 @@ Devel::PerlySense::Project object.
 Default: A Devel::PerlySense::Project::Unknown object.
 
 =cut
-field "oProject" => Devel::PerlySense::Project::Unknown->new();
+field "oProject" => undef;
 
 
 
@@ -1735,6 +1735,7 @@ Create new PerlySense object.
 sub new() {
     my $self = bless {}, shift;
     $self->oBookmarkConfig(Devel::PerlySense::BookmarkConfig->new( oPerlySense => $self ));
+    $self->oProject(Devel::PerlySense::Project::Unknown->new( oPerlySense => $self ));
     return($self);
 }
 
